@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2016-2018 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2016-2019 -- leonerd@leonerd.org.uk
 
 package Syntax::Keyword::Try;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09_001';
+our $VERSION = '0.11_001';
 
 use Carp;
 
@@ -95,10 +95,20 @@ still propagate exceptions up to callers as normal.
       STATEMENTS...
    }
 
+Or
+
+   ...
+   catch my $var {
+      STATEMENTS...
+   }
+
+I<Since version NEXT.>
+
 A C<catch> statement provides a block of code to the preceding C<try>
 statement that will be invoked in the case that the main block of code throws
 an exception. The C<catch> block can inspect the raised exception by looking
-in C<$@> in the usual way.
+in C<$@> in the usual way. Optionally, a new lexical variable can be
+introduced to store the exception in.
 
 Presence of this C<catch> statement causes any exception thrown by the
 preceding C<try> block to be non-fatal to the surrounding code. If the
@@ -153,22 +163,30 @@ The syntax provided by this module may be used as a value-yielding expression.
 Because this syntax is new, experimental, and somewhat surprising, it must be
 specifically requested by name C<try_value>:
 
-   use Syntax::Feature::Try qw( try try_value );
+   use Syntax::Keyword::Try qw( try try_value );
 
    my $result = try do { ... } catch { ... };
 
+Also, on Perl versions 5.24 and later:
+
+   my $result = try do { ... } finally { ... };
+
+   my $result = try do { ... } catch { ... } finally { ... };
+
 Specifically, note that the expression must be spelled as C<try do { ... }> so
 that the syntax is distinct from that used by control-flow statements. The
 interposed C<do> keyword reminds the reader, and instructs the syntax parser,
 that this will be an expression, not a statement. It is not necessary to
-similarly notate the C<catch> block.
+similarly notate the C<catch> or C<finally> blocks.
 
 In this case, the syntax behaves syntactically like an expression, and may
 appear anywhere a normal expression is allowed. It follows similar semantics
 to the purely control-flow case; if the code in the C<try> block does not
 throw an exception, then the expression as a whole yields whatever value the
 C<try> expression did. If it fails, then the C<catch> block is executed and
-the expression yields its resulting value instead.
+the expression yields its resulting value instead. A C<finally> block, if
+present, will be evaluated for side-effects before the rest of the expression
+returns.
 
 Remember that, as in the control-flow case, the C<return> keyword will cause
 the entire containing function to return, not just the C<try> block.
@@ -248,8 +266,7 @@ only works as a syntax-level statement and not an expression when the
 experimental C<try_value> feature described above has not been enabled. You
 cannot assign from the result of a C<try> block. Additionally,
 final-expression value semantics do not work, so it cannot be contained by a
-C<do> block to yield this value. See above for a workaround involving an
-anonymous sub however.
+C<do> block to yield this value.
 
 In comparison, the behaviour implemented by L<Try::Tiny> can be used as a
 valued expression, such as assigned to a variable or returned to the caller of
@@ -306,9 +323,35 @@ sub import_into
    $^H{"Syntax::Keyword::Try/try"}++ if delete $syms{try};
    $^H{"Syntax::Keyword::Try/try_value"}++ if delete $syms{try_value};
 
+   # Ignore requests for these, as they come automatically with `try`
+   delete @syms{qw( catch finally )};
+
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
+=head1 WITH OTHER MODULES
+
+=head2 Future::AsyncAwait
+
+As of C<Future::AsyncAwait> version 0.10 and L<Syntax::Keyword::Try> version
+0.07, cross-module integration tests assert that basic C<try/catch> blocks
+inside an C<async sub> work correctly, including those that attempt to
+C<return> from inside C<try>.
+
+   use Future::AsyncAwait;
+   use Syntax::Keyword::Try;
+
+   async sub attempt
+   {
+      try {
+         await func();
+         return "success";
+      }
+      catch {
+         return "failed";
+      }
+   }
+
 =head1 KNOWN BUGS
 
 =head2 Thread-safety at load time cannot be assured before perl 5.16
